@@ -27,7 +27,7 @@ module Paint
         substitutions.each{ |key, value|
           string.gsub!(
             "%{#{key}}",
-            (value.is_a?(Array) ? self%[value, current_color] : value.to_s)
+            (value.is_a?(Array) ? self.%(value, current_color) : value.to_s)
           )
         }
       end
